@@ -20,11 +20,13 @@ urlpatterns = [
     url(r'^$', flat.views.index, name='index'),
     url(r'^index/?$', flat.views.index, name='index'),
     url(r'^pub/?$', flat.views.pub, name='pub'),
+    url(r'^config/?$', flat.views.config, name='config'),
     url(r'^index/(?P<namespace>[\w\d\-_\./@]+)/?$', flat.views.index, name='index'),
     url(r'^login/?$', flat.views.login, name='login'),
+    url(r'^selectconf/?$', flat.views.selectconf, name='selectconf'),
     url(r'^logout/?$', flat.views.logout, name='logout'),
     url(r'^account/', include('django.contrib.auth.urls')),
-    url(r'^admin/', include(admin.site.urls)),
+    url(r'^admin/', admin.site.urls if VERSION[0] >= 2 else include(admin.site.urls)),
     url(r'^admin/doc/', include('django.contrib.admindocs.urls')),
     url(r'^register/?$', flat.views.register, name='register'),
     url(r'^download/pub/(?P<docid>[\w\d\-_\.]+)\.folia\.xml/?$', flat.views.pub_download, name='download'),
@@ -37,8 +39,8 @@ urlpatterns = [
     url(r'^addnamespace/?$', flat.views.addnamespace, name='addnamespace'),
     url(r'^pub/(?P<configuration>[\w\d\-_\./@]+)/(?P<docid>[\w\d\-_\.]+)/query/?$', flat.views.pub_query, name='query'), #generic query function
     url(r'^(?P<namespace>[\w\d\-_\./@]+)/(?P<docid>[\w\d\-_\.]+)/query/?$', flat.views.query, name='query'), #generic query function
+    url('^oidc/', include('mozilla_django_oidc.urls')),
     # url(r'^flat/', include('flat.foo.urls')),
-
 ]
 
 if VERSION[0] == 1 and VERSION[1] < 8: #Django <1.8
@@ -47,10 +49,12 @@ if VERSION[0] == 1 and VERSION[1] < 8: #Django <1.8
 if settings.DEBUG:
     if VERSION[0] > 1 or VERSION[1] >= 6: #Django 1.6
         urlpatterns += static(settings.STYLE_URL, document_root=settings.STYLE_ROOT)
+        urlpatterns += static(settings.SCRIPT_URL, document_root=settings.SCRIPT_ROOT)
     else:
         #Django 1.3
         urlpatterns += patterns('',
             (r'^style/(?P<path>.*)$', 'django.views.static.serve', {'document_root': settings.STYLE_ROOT}),
+            (r'^script/(?P<path>.*)$', 'django.views.static.serve', {'document_root': settings.SCRIPT_ROOT}),
         )
 
 
