@@ -40,6 +40,7 @@ def getcontext(request,namespace,docid, doc, mode, configuration = None):
         authenticated = request.user.is_authenticated if isinstance(request.user.is_authenticated, bool) else request.user.is_authenticated()
     else:
         authenticated = False
+    oidc = settings.OIDC if hasattr(settings, 'OIDC') else False
     return {
             'base_prefix': settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else "",
             'configuration_id': configuration,
@@ -66,7 +67,8 @@ def getcontext(request,namespace,docid, doc, mode, configuration = None):
             'loggedin': authenticated,
             'isadmin': request.user.is_staff if request.user else False,
             'version': settings.VERSION,
-            'username': request.user.username if namespace != "pub" else "anonymous",
+            'username': request.user.email if oidc and namespace != 'pub' else request.user.username if namespace != "pub" else "anonymous",
+            'oidc': oidc,
             'waitmessage': "Loading document on server and initialising web-environment...",
     }
 
@@ -219,7 +221,7 @@ def query_helper(request,namespace, docid, configuration=None):
             needwritepermission = False
 
     if namespace != "pub":
-        if needwritepermission and not flat.users.models.haswritepermission(request.user.username, namespace, request):
+        if needwritepermission and not flat.users.models.haswritepermission(getusername(request), namespace, request):
             return HttpResponseForbidden("Permission denied, no write access")
 
     query = "\n".join(data['queries']) #throw all queries on a big pile to transmit
@@ -240,7 +242,7 @@ def query(request,namespace, docid):
     if request.method != 'POST':
         return HttpResponseForbidden("POST method required for " + namespace + "/" + docid + "/query")
 
-    if flat.users.models.hasreadpermission(request.user.username, namespace, request):
+    if flat.users.models.hasreadpermission(getusername(request), namespace, request):
         return query_helper(request, namespace,docid, request.session['configuration'])
     else:
         return HttpResponseForbidden("Permission denied, no read access")
@@ -253,6 +255,8 @@ def pub_query(request,configuration, docid):
     return query_helper(request, 'pub',docid, configuration)
 
 def login(request):
+    oidc = settings.OIDC if hasattr(settings, 'OIDC') else False
+    loggedin = request.user.is_authenticated if isinstance(request.user.is_authenticated, bool) else request.user.is_authenticated()
     if 'username' in request.POST and 'password' in request.POST:
         username = request.POST['username']
         password = request.POST['password']
@@ -271,12 +275,12 @@ def login(request):
                     return redirect(base_prefix + "/")
             else:
                 # Return a 'disabled account' error message
-                return render(request, 'login.html', {'error': "This account is disabled","defaultconfiguration":settings.DEFAULTCONFIGURATION, "configurations":settings.CONFIGURATIONS , 'version': settings.VERSION, "allowregistration": hasattr(settings, 'ALLOWREGISTRATION') and settings.ALLOWREGISTRATION,'base_prefix': settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else "" } )
+                return render(request, 'login.html', {'error': "This account is disabled","defaultconfiguration":settings.DEFAULTCONFIGURATION, "configurations":settings.CONFIGURATIONS , 'version': settings.VERSION, "allowregistration": hasattr(settings, 'ALLOWREGISTRATION') and settings.ALLOWREGISTRATION,'base_prefix': settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else "", 'oidc': oidc, 'username': 'anonymous' if not loggedin else request.user.email if oidc else request.user.username, 'loggedin': loggedin } )
         else:
             # Return an 'invalid login' error message.
-            return render(request, 'login.html', {'error': "Invalid username or password","defaultconfiguration":settings.DEFAULTCONFIGURATION, "configurations":settings.CONFIGURATIONS, 'version': settings.VERSION, "allowregistration": hasattr(settings, 'ALLOWREGISTRATION') and settings.ALLOWREGISTRATION,'base_prefix': settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else "" } )
+            return render(request, 'login.html', {'error': "Invalid username or password","defaultconfiguration":settings.DEFAULTCONFIGURATION, "configurations":settings.CONFIGURATIONS, 'version': settings.VERSION, "allowregistration": hasattr(settings, 'ALLOWREGISTRATION') and settings.ALLOWREGISTRATION,'base_prefix': settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else "", 'oidc': oidc,   'username': 'anonymous' if not loggedin else request.user.email if oidc else request.user.username, 'loggedin': loggedin} )
     else:
-        return render(request, 'login.html',{"defaultconfiguration":settings.DEFAULTCONFIGURATION, "configurations":settings.CONFIGURATIONS, "version": settings.VERSION, "allowregistration": hasattr(settings, 'ALLOWREGISTRATION') and settings.ALLOWREGISTRATION,'base_prefix': settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else "" })
+        return render(request, 'login.html',{"defaultconfiguration":settings.DEFAULTCONFIGURATION, "configurations":settings.CONFIGURATIONS, "version": settings.VERSION, "allowregistration": hasattr(settings, 'ALLOWREGISTRATION') and settings.ALLOWREGISTRATION,'base_prefix': settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else "", 'oidc': oidc, 'username': 'anonymous' if not loggedin else request.user.email if oidc else request.user.username, 'loggedin': loggedin })
 
 
 def logout(request):
@@ -302,7 +306,8 @@ def register(request):
     return render(request, "register.html", {
         'form': form,
         'version': settings.VERSION,
-        'base_prefix':  base_prefix
+        'base_prefix':  base_prefix,
+        'oidc': False
     })
 
 def fatalerror(request, e,code=404):
@@ -310,10 +315,25 @@ def fatalerror(request, e,code=404):
     if isinstance(e, Exception):
         response = render(request,'base.html', docserveerror(e))
     else:
-        response = render(request,'base.html', {'fatalerror': str(e),'base_prefix': settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else ""})
+        response = render(request,'base.html', {'fatalerror': str(e),'base_prefix': settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else "", 'oidc': settings.OIDC if hasattr(settings, 'OIDC') else False })
     response.status_code = code
     return response
 
+def getusername(request):
+    if hasattr(settings, 'OIDC') and settings.OIDC:
+        return request.user.email
+    return request.user.username
+
+@login_required
+def selectconf(request):
+    oidc = settings.OIDC if hasattr(settings, 'OIDC') else False
+    loggedin = request.user.is_authenticated if isinstance(request.user.is_authenticated, bool) else request.user.is_authenticated()
+    if 'configuration' in request.POST:
+        request.session['configuration'] = request.POST['configuration']
+        base_prefix = settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else ""
+        return HttpResponseRedirect(base_prefix + "/index/")
+
+    return render(request, 'selectconf.html',{"defaultconfiguration":settings.DEFAULTCONFIGURATION, "configurations":settings.CONFIGURATIONS, "version": settings.VERSION, "allowregistration": hasattr(settings, 'ALLOWREGISTRATION') and settings.ALLOWREGISTRATION,'base_prefix': settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else "", 'oidc': oidc, 'username': 'anonymous' if not loggedin else request.user.email if oidc else request.user.username, 'loggedin': loggedin })
 
 @login_required
 def index(request, namespace=""):
@@ -323,13 +343,14 @@ def index(request, namespace=""):
         return fatalerror(request,e)
 
     if not 'configuration' in request.session:
-        return logout(request)
+        base_prefix = settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else ""
+        return HttpResponseRedirect(base_prefix + "/selectconf/")
 
     if not namespace:
         #check if user namespace is preset, if not, make it
-        if not request.user.username in namespaces['namespaces']:
+        if getusername(request) not in namespaces['namespaces']:
             try:
-                flat.comm.get(request, "createnamespace/" + request.user.username, False)
+                flat.comm.get(request, "createnamespace/" + getusername(request), False)
             except Exception as e:
                 return fatalerror(request,e)
 
@@ -345,16 +366,19 @@ def index(request, namespace=""):
             for group in request.user.groups.all():
                 for user in django.contrib.auth.models.User.objects.filter(groups__name=group.name):
                     try:
-                        flat.comm.get(request, "createnamespace/" + user.username, False)
+                        if hasattr(settings, 'OIDC') and settings.OIDC:
+                            flat.comm.get(request, "createnamespace/" + user.email, False)
+                        else:
+                            flat.comm.get(request, "createnamespace/" + user.username, False)
                     except Exception as e:
                         return fatalerror(request,e)
 
-    readpermission = flat.users.models.hasreadpermission(request.user.username, namespace, request)
+    readpermission = flat.users.models.hasreadpermission(getusername(request), namespace, request)
     dirs = []
     recursivedirs =  []
     subdirs =[]
     for ns in sorted(namespaces['namespaces']):
-        if flat.users.models.hasreadpermission(request.user.username, ns, request):
+        if flat.users.models.hasreadpermission(getusername(request), ns, request):
             recursivedirs.append(ns)
             if '/' not in ns:
                 dirs.append(ns)
@@ -392,12 +416,13 @@ def index(request, namespace=""):
         parentdir = '/'.join(namespace.split('/')[:-1])
     else:
         parentdir = ""
-
-    return render(request, 'index.html', {'namespace': namespace,'parentdir': parentdir, 'dirs': dirs, 'recursivedirs': recursivedirs, 'subdirs': subdirs, 'docs': docs, 'defaultmode': settings.DEFAULTMODE,'loggedin': request.user.is_authenticated if isinstance(request.user.is_authenticated, bool) else request.user.is_authenticated(), 'isadmin': request.user.is_staff, 'username': request.user.username, 'configuration': settings.CONFIGURATIONS[request.session['configuration']], 'converters': get_converters(request), 'inputformatchangefunction': inputformatchangefunction(request), 'allowcopy': request.user.has_perm('auth.allowcopy'), 'allowdelete': request.user.has_perm('auth.allowdelete'),'version': settings.VERSION,'base_prefix': settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else ""})
+    oidc = settings.OIDC if hasattr(settings, 'OIDC') else False
+    return render(request, 'index.html', {'namespace': namespace,'parentdir': parentdir, 'dirs': dirs, 'recursivedirs': recursivedirs, 'subdirs': subdirs, 'docs': docs, 'defaultmode': settings.DEFAULTMODE,'loggedin': request.user.is_authenticated if isinstance(request.user.is_authenticated, bool) else request.user.is_authenticated(), 'isadmin': request.user.is_staff, 'username': request.user.email if oidc else request.user.username, 'configuration': settings.CONFIGURATIONS[request.session['configuration']], 'converters': get_converters(request), 'inputformatchangefunction': inputformatchangefunction(request), 'allowcopy': request.user.has_perm('auth.allowcopy'), 'allowdelete': request.user.has_perm('auth.allowdelete'),'version': settings.VERSION,'base_prefix': settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else "", 'oidc': oidc})
 
 def pub(request):
+    oidc = settings.OIDC if hasattr(settings, 'OIDC') else False
     if hasattr(settings,'ALLOWPUBLICUPLOAD') and settings.ALLOWPUBLICUPLOAD:
-        return render(request, 'pub.html', {'defaultmode': settings.DEFAULTMODE,'loggedin': request.user.is_authenticated if isinstance(request.user.is_authenticated, bool) else request.user.is_authenticated(), 'isadmin': request.user.is_staff, 'username': request.user.username,"defaultconfiguration":settings.DEFAULTCONFIGURATION, "configurations":settings.CONFIGURATIONS, 'version': settings.VERSION,'base_prefix': settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else ""})
+        return render(request, 'pub.html', {'defaultmode': settings.DEFAULTMODE,'loggedin': request.user.is_authenticated if isinstance(request.user.is_authenticated, bool) else request.user.is_authenticated(), 'isadmin': request.user.is_staff, 'username': request.user.email if oidc else request.user.username,"defaultconfiguration":settings.DEFAULTCONFIGURATION, "configurations":settings.CONFIGURATIONS, 'version': settings.VERSION,'base_prefix': settings.BASE_PREFIX if hasattr(settings,'BASE_PREFIX') else "", 'oidc': oidc })
     else:
         return fatalerror(request, "Public anonymous write permission denied",403)
 
@@ -432,7 +457,7 @@ def filemanagement(request):
                 return fatalerror(request, "No documents selected",404)
 
             if targetnamespace:
-                if not flat.users.models.haswritepermission(request.user.username, targetnamespace, request):
+                if not flat.users.models.haswritepermission(getusername(request), targetnamespace, request):
                     return fatalerror(request, "Write permission denied for " + targetnamespace,403)
 
             namespace = None
@@ -443,9 +468,9 @@ def filemanagement(request):
                 else:
                     data = {}
 
-                if not flat.users.models.hasreadpermission(request.user.username, namespace, request):
+                if not flat.users.models.hasreadpermission(getusername(request), namespace, request):
                     return fatalerror(request, "Read permission denied for " + docid,403)
-                if request.POST['filemanmode'] in ('delete','move') and not flat.users.models.haswritepermission(request.user.username, namespace, request):
+                if request.POST['filemanmode'] in ('delete','move') and not flat.users.models.haswritepermission(getusername(request), namespace, request):
                     return fatalerror(request, "Write permission denied for " + docid,403)
 
                 try:
@@ -547,7 +572,7 @@ def upload_helper(request, namespace, configuration=None, mode=None):
 def upload(request):
     if request.method == 'POST':
         namespace = request.POST['namespace'].replace('..','.').replace(' ','').replace('&','')
-        if flat.users.models.haswritepermission(request.user.username, namespace, request) and 'file' in request.FILES:
+        if flat.users.models.haswritepermission(getusername(request), namespace, request) and 'file' in request.FILES:
             return upload_helper(request, namespace)
         else:
             return fatalerror(request, "Write permission denied",403)
@@ -585,7 +610,7 @@ def addnamespace(request):
     if request.method == 'POST':
         namespace = request.POST['namespace'].replace('/','').replace('..','.').replace(' ','').replace('&','')
         newdirectory = request.POST['newdirectory'].replace('/','').replace('..','.').replace(' ','').replace('&','')
-        if flat.users.models.haswritepermission(request.user.username, namespace, request):
+        if flat.users.models.haswritepermission(getusername(request), namespace, request):
             try:
                 response = flat.comm.get(request,"createnamespace/" + namespace + "/" + newdirectory)
             except Exception as e:
