@@ -203,8 +203,10 @@ CONFIGURATIONS = {
     #Enable editing as new, this allows for adding multiple or overlapping annotations of the same type
     'editformnew': True, #boolean
 
+    #Enable editing the structure element (i.e. its class)
+    'editstructure': True,
 
-    #This defines what edit modes the user can enable/disable from the menu
+    #This defines what edit modes the user can enable/disable from the menu himself/herself
     'alloweditformdirect': True, #boolean
     'alloweditformcorrection': True, #boolean
     'alloweditformalternative': True, #boolean
@@ -213,9 +215,10 @@ CONFIGURATIONS = {
     #Allow confidence values to be set/edited?
     'allowconfidence': True,
 
-    #Allow editing the structure element (i.e. its class)
+    #Allow enabling/disabling editing the structure element (i.e. its class)
     'alloweditstructure': True,
 
+
     # FoLiA set to use for corrections
     #'initialcorrectionset': 'http://raw.github.com/proycon/folia/master/setdefinitions/spellingcorrection.foliaset.xml',
 
@@ -294,7 +297,40 @@ SECRET_KEY = 'ki5^nfv01@1g7(+*#l_0fmi9h&cf^_lv6bs4j9^6mpr&(%o4zk'
 
 DEBUG = True #Set to False for production environments!!!!
 
+#Enable the following if you are behind a HTTPS proxy (you should be if you run a public instance!)
+#Make sure your reverse proxy sets and forwards the X-Forwarded-Proto header, and strips it from incoming user request
+#SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')
 
+##############################################################################
+# DJANGO SETTINGS FOR OPENID CONNECT AUTHENTICATION
+#############################################################################
+
+OIDC = False #Set this to True if you want want OpenID Connect Authentication,
+             #and uncomment and fill all lines below
+
+    #note: The redirect url you register with your authorization provider should end in /oidc/callback/
+
+#AUTHENTICATION_BACKENDS = ( 'django.contrib.auth.backends.ModelBackend','mozilla_django_oidc.auth.OIDCAuthenticationBackend',)
+
+#OIDC_RP_CLIENT_ID = "" #As provided by your authorization provider, do not check this into public version control!!!
+#OIDC_RP_CLIENT_SECRET = ""#As provider by your authorization provider, Do not check this into public version control!!!
+
+
+#OIDC_OP_AUTHORIZATION_ENDPOINT = "<URL of the OIDC OP authorization endpoint>"
+#OIDC_OP_TOKEN_ENDPOINT = "<URL of the OIDC OP token endpoint>"
+#OIDC_OP_USER_ENDPOINT = "<URL of the OIDC OP userinfo endpoint>"
+
+   #You may also need the following for OpenID Connect:
+#OIDC_TOKEN_USE_BASIC_AUTH = True  #Use client_secret_basic, if not enabled, client_secret_post will be default
+#OIDC_RP_SIGN_ALGO = "RS256" #should be HS256 or RS256
+#OIDC_OP_JWKS_ENDPOINT = "<URL of the OIDC OP JWKS endpoint>" #to obtain the signing key automatically
+#OIDC_RP_IDP_SIGN_KEY = {    #OR provide the key manually:
+#      "kty": "RSA",
+#      "use": "sig",
+#      "alg": "RS256",
+#      "n": "<to be filled!>",
+#      "e": "AQAB"
+#}
 
 ##############################################################################
 # DJANGO SETTINGS THAT NEED NOT BE CHANGED (but you may if you want to, do scroll through at least)
@@ -469,11 +505,15 @@ INSTALLED_APPS = [
     # 'django.contrib.admindocs',
     'flat.users'
 ]
+if OIDC: INSTALLED_APPS.insert(1, 'mozilla_django_oidc')
 for mode,_ in MODES:
     INSTALLED_APPS.append('flat.modes.' + mode)
 INSTALLED_APPS = tuple(INSTALLED_APPS)
 
 
+LOGIN_REDIRECT_URL = BASE_PREFIX + "/"
+LOGOUT_REDIRECT_URL = BASE_PREFIX + "/"
+
 SESSION_SERIALIZER = 'django.contrib.sessions.serializers.JSONSerializer'
 
 
